@@ -1,7 +1,7 @@
 from __future__ import absolute_import
 
 generic_globals = dict(globals())
-generic_locals  = dict(locals())
+generic_globals.update(dict(locals()))
 
 import inspect
 import os
@@ -21,7 +21,12 @@ def include(relative_path_to_other_file, your_globals=None):
       >>> include.include('file.py', globals())
       >>> # you now have access to all the funcs/vars from 'file.py'
     '''
-    path_to_file = resolve_path(relative_path_to_other_file, upstack=1)
+    if not your_globals:
+        your_globals = {}
+
+    if not your_globals.get("__file__", None):
+        your_globals["__file__"] = os.getcwd() + "/<REPL>"
+    path_to_file = os.path.abspath(os.path.join(os.path.dirname(your_globals["__file__"]), relative_path_to_other_file))
     
     # init your_globals if the argument wasn't included
     if your_globals == None:
@@ -29,51 +34,35 @@ def include(relative_path_to_other_file, your_globals=None):
     
     # if file hasn't been loaded yet
     if not (path_to_file in __ALL_MODULES__):
-        their_locals = dict(generic_globals)
-        their_globals = dict(generic_locals)
+        their_globals = dict(generic_globals)
+        their_globals.update(your_globals)
         # set their path so things don't break
         their_globals['__file__'] = path_to_file
-        their_locals['__file__'] = path_to_file
         output = ""
         with open(path_to_file,'r') as f:
             output = f.read()
         try:
-            exec(output, their_globals, their_locals)
+            exec(output, their_globals, their_globals)
         except Exception as error:
             import traceback
+            # traceback_tuple = traceback.format_list(traceback.extract_tb(error.__traceback__))
             traceback_str = traceback.format_exc()
-            raise Exception(traceback_str + "\n\nError on: " + path_to_file + ":" + str(error.__traceback__.tb_next.tb_lineno) + "\nfrom the include(\'"+relative_path_to_other_file+"\')")
-        their_globals.update(their_locals)
+            
+            # for some reason sometimes the "tb_next" doesn't exist and then its hard to get the actual line number
+            line_number = ""
+            if error.__traceback__.tb_next:
+                line_number = ":" + str(tb_frame.tb_lineno)
+            
+            raise Exception(traceback_str + "\n\nError from: " + path_to_file + line_number + "\nfrom the include(\'"+relative_path_to_other_file+"\')")
+        
         __ALL_MODULES__[path_to_file] = their_globals
     
     # combine their globals into your globals
     their_globals = __ALL_MODULES__[path_to_file]
+    # remove the one thing that should be unique to their file
+    if "__file__" in their_globals:
+        del their_globals["__file__"]
     # put their globals into your file
     your_globals.update(their_globals)
     # return the globals for good measure
-    return your_globals
-
-def resolve_path(path, upstack=0):
-    # this function was pulled from https://github.com/pcattori/require.py 
-    # you can tell because it has good docstrings
-    '''Resolve a path to an absolute path by taking it to be relative to the source
-    code of the caller's stackframe shifted up by `upstack` frames.
-
-    :param str path: Filesystem path
-    :param int upstack: Number of stackframes upwards from caller's stackframe
-    to act as relative point.
-
-    #: TODO Usage example is not great on REPL...
-
-    Usage::
-      >>> import require # at /home/require
-      >>> require.resolve_path('file.txt')
-      '/home/require/file.txt'
-    '''
-    if os.path.isabs(path):
-        return path
-    # get absolute path by rooting path with calling script directory
-    # TODO guard rails for upstack? 
-    caller_relative_filepath = inspect.stack()[upstack + 1][1]
-    caller_root = os.path.dirname(os.path.abspath(caller_relative_filepath))
-    return os.path.abspath(os.path.join(caller_root, path))
+    return your_globals
\ No newline at end of file
